@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import List
-from splitiorequests.models.splits.matcher import Matcher
+
+from .matcher import Matcher
 
 
 @dataclass
