@@ -1,7 +1,11 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import List, Optional
-from splitiorequests.models.splits.depends import Depends
-from splitiorequests.models.splits.between import Between
+
+from .depends import Depends
+from .between import Between
 
 
 @dataclass
