@@ -1,7 +1,11 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import List, Optional
-from splitiorequests.models.splits.traffic_type import TrafficType
-from splitiorequests.models.splits.tag import Tag
+
+from .traffic_type import TrafficType
+from .tag import Tag
 
 
 @dataclass
