@@ -1,10 +1,14 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import Optional, List
-from splitiorequests.models.splits.treatment import Treatment
-from splitiorequests.models.splits.default_rule import DefaultRule
-from splitiorequests.models.splits.environment import Environment
-from splitiorequests.models.splits.traffic_type import TrafficType
-from splitiorequests.models.splits.rule import Rule
+
+from .treatment import Treatment
+from .default_rule import DefaultRule
+from .environment import Environment
+from .traffic_type import TrafficType
+from .rule import Rule
 
 
 @dataclass
