@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import List
-from splitiorequests.models.splits.split_definition import SplitDefinition
+
+from .split_definition import SplitDefinition
 
 
 @dataclass
