@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump
+
 from splitiorequests.models.splits.condition import Condition
-from splitiorequests.schemas.splits.matcher_schema import MatcherSchema
+from .matcher_schema import MatcherSchema
 
 
 class ConditionSchema(Schema):
