@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
+
 from splitiorequests.models.splits.condition import Condition
-from splitiorequests.schemas.splits.matcher_schema_exclude import MatcherSchemaExclude
+from .matcher_schema_exclude import MatcherSchemaExclude
 
 
 class ConditionSchemaExclude(Schema):
