@@ -1,5 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load
-from splitiorequests.schemas.splits import between_schema, depends_schema
+
+from .between_schema import BetweenSchema
+from .depends_schema import DependsSchema
 from splitiorequests.models.splits.matcher import Matcher
 
 
@@ -11,10 +16,10 @@ class MatcherSchema(Schema):
     negate = fields.Bool()
     attribute = fields.Str()
     string = fields.Str()
-    depends = fields.Nested(depends_schema.DependsSchema)
+    depends = fields.Nested(DependsSchema)
     strings = fields.List(fields.Str())
     date = fields.Int()
-    between = fields.Nested(between_schema.BetweenSchema)
+    between = fields.Nested(BetweenSchema)
     number = fields.Int()
     bool = fields.Bool()
 
