@@ -1,5 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load, EXCLUDE
-from splitiorequests.schemas.splits import between_schema_exclude, depends_schema_exclude
+
+from .between_schema_exclude import BetweenSchemaExclude
+from .depends_schema_exclude import DependsSchemaExclude
 from splitiorequests.models.splits.matcher import Matcher
 
 
@@ -12,10 +17,10 @@ class MatcherSchemaExclude(Schema):
     negate = fields.Bool()
     attribute = fields.Str()
     string = fields.Str()
-    depends = fields.Nested(depends_schema_exclude.DependsSchemaExclude)
+    depends = fields.Nested(DependsSchemaExclude)
     strings = fields.List(fields.Str())
     date = fields.Int()
-    between = fields.Nested(between_schema_exclude.BetweenSchemaExclude)
+    between = fields.Nested(BetweenSchemaExclude)
     number = fields.Int()
     bool = fields.Bool()
 
