@@ -1,5 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump
-from splitiorequests.schemas.splits import bucket_schema, condition_schema
+
+from .bucket_schema import BucketSchema
+from .condition_schema import ConditionSchema
 from splitiorequests.models.splits.rule import Rule
 
 
@@ -7,8 +12,8 @@ class RuleSchema(Schema):
     class Meta:
         ordered = True
 
-    buckets = fields.List(fields.Nested(bucket_schema.BucketSchema), required=True)
-    condition = fields.Nested(condition_schema.ConditionSchema, required=True)
+    buckets = fields.List(fields.Nested(BucketSchema), required=True)
+    condition = fields.Nested(ConditionSchema, required=True)
 
     @post_load
     def load_rule(self, data, **kwargs):
