@@ -1,5 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
-from splitiorequests.schemas.splits import bucket_schema_exclude, condition_schema_exclude
+
+from .bucket_schema_exclude import BucketSchemaExclude
+from .condition_schema_exclude import ConditionSchemaExclude
 from splitiorequests.models.splits.rule import Rule
 
 
@@ -8,8 +13,8 @@ class RuleSchemaExclude(Schema):
         unknown = EXCLUDE
         ordered = True
 
-    buckets = fields.List(fields.Nested(bucket_schema_exclude.BucketSchemaExclude), required=True)
-    condition = fields.Nested(condition_schema_exclude.ConditionSchemaExclude, required=True)
+    buckets = fields.List(fields.Nested(BucketSchemaExclude), required=True)
+    condition = fields.Nested(ConditionSchemaExclude, required=True)
 
     @post_load
     def load_rule(self, data, **kwargs):
