@@ -1,7 +1,14 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load
+
+from .traffic_type_schema import TrafficTypeSchema
+from .rule_schema import RuleSchema
+from .treatment_schema import TreatmentSchema
+from .default_rule_schema import DefaultRuleSchema
+from .environment_schema import EnvironmentSchema
 from splitiorequests.models.splits.split_definition import SplitDefinition
-from splitiorequests.schemas.splits import traffic_type_schema, rule_schema, treatment_schema, default_rule_schema, \
-    environment_schema
 
 
 class SplitDefinitionSchema(Schema):
@@ -9,15 +16,15 @@ class SplitDefinitionSchema(Schema):
         ordered = True
 
     name = fields.Str()
-    environment = fields.Nested(environment_schema.EnvironmentSchema)
-    trafficType = fields.Nested(traffic_type_schema.TrafficTypeSchema)
+    environment = fields.Nested(EnvironmentSchema)
+    trafficType = fields.Nested(TrafficTypeSchema)
     killed = fields.Bool()
-    treatments = fields.List(fields.Nested(treatment_schema.TreatmentSchema), required=True)
+    treatments = fields.List(fields.Nested(TreatmentSchema), required=True)
     defaultTreatment = fields.Str(required=True)
     baselineTreatment = fields.Str()
     trafficAllocation = fields.Int()
-    rules = fields.List(fields.Nested(rule_schema.RuleSchema))
-    defaultRule = fields.List(fields.Nested(default_rule_schema.DefaultRuleSchema), required=True)
+    rules = fields.List(fields.Nested(RuleSchema))
+    defaultRule = fields.List(fields.Nested(DefaultRuleSchema), required=True)
     creationTime = fields.Int()
     lastUpdateTime = fields.Int()
     comment = fields.Str()
