@@ -1,12 +1,14 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load, EXCLUDE
+
+from .traffic_type_schema_exclude import TrafficTypeSchemaExclude
+from .rule_schema_exclude import RuleSchemaExclude
+from .treatment_schema_exclude import TreatmentSchemaExclude
+from .default_rule_schema_exclude import DefaultRuleSchemaExclude
+from .environment_schema_exclude import EnvironmentSchemaExclude
 from splitiorequests.models.splits.split_definition import SplitDefinition
-from splitiorequests.schemas.splits import (
-    traffic_type_schema_exclude,
-    rule_schema_exclude,
-    treatment_schema_exclude,
-    default_rule_schema_exclude,
-    environment_schema_exclude
-)
 
 
 class SplitDefinitionSchemaExclude(Schema):
@@ -15,15 +17,15 @@ class SplitDefinitionSchemaExclude(Schema):
         ordered = True
 
     name = fields.Str()
-    environment = fields.Nested(environment_schema_exclude.EnvironmentSchemaExclude)
-    trafficType = fields.Nested(traffic_type_schema_exclude.TrafficTypeSchemaExclude)
+    environment = fields.Nested(EnvironmentSchemaExclude)
+    trafficType = fields.Nested(TrafficTypeSchemaExclude)
     killed = fields.Bool()
-    treatments = fields.List(fields.Nested(treatment_schema_exclude.TreatmentSchemaExclude), required=True)
+    treatments = fields.List(fields.Nested(TreatmentSchemaExclude), required=True)
     defaultTreatment = fields.Str(required=True)
     baselineTreatment = fields.Str()
     trafficAllocation = fields.Int()
-    rules = fields.List(fields.Nested(rule_schema_exclude.RuleSchemaExclude))
-    defaultRule = fields.List(fields.Nested(default_rule_schema_exclude.DefaultRuleSchemaExclude), required=True)
+    rules = fields.List(fields.Nested(RuleSchemaExclude))
+    defaultRule = fields.List(fields.Nested(DefaultRuleSchemaExclude), required=True)
     creationTime = fields.Int()
     lastUpdateTime = fields.Int()
     comment = fields.Str()
