@@ -1,5 +1,9 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump
-from splitiorequests.schemas.splits.split_definition_schema import SplitDefinitionSchema
+
+from .split_definition_schema import SplitDefinitionSchema
 from splitiorequests.models.splits.split_definitions import SplitDefinitions
 
 
