@@ -1,5 +1,9 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
-from splitiorequests.schemas.splits.split_definition_schema_exclude import SplitDefinitionSchemaExclude
+
+from .split_definition_schema_exclude import SplitDefinitionSchemaExclude
 from splitiorequests.models.splits.split_definitions import SplitDefinitions
 
 
