@@ -1,6 +1,11 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load
+
+from .tag_schema import TagSchema
+from .traffic_type_schema import TrafficTypeSchema
 from splitiorequests.models.splits.split import Split
-from splitiorequests.schemas.splits import tag_schema, traffic_type_schema
 
 
 class SplitSchema(Schema):
@@ -9,9 +14,9 @@ class SplitSchema(Schema):
 
     name = fields.Str(required=True)
     description = fields.Str()
-    trafficType = fields.Nested(traffic_type_schema.TrafficTypeSchema)
+    trafficType = fields.Nested(TrafficTypeSchema)
     creationTime = fields.Integer()
-    tags = fields.List(fields.Nested(tag_schema.TagSchema), missing=None)
+    tags = fields.List(fields.Nested(TagSchema), missing=None)
 
     @post_load
     def load_split(self, data, **kwargs):
