@@ -1,6 +1,11 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_dump, post_load, EXCLUDE
+
+from .tag_schema_exclude import TagSchemaExclude
+from .traffic_type_schema_exclude import TrafficTypeSchemaExclude
 from splitiorequests.models.splits.split import Split
-from splitiorequests.schemas.splits import tag_schema_exclude, traffic_type_schema_exclude
 
 
 class SplitSchemaExclude(Schema):
@@ -10,9 +15,9 @@ class SplitSchemaExclude(Schema):
 
     name = fields.Str(required=True)
     description = fields.Str(missing=None)
-    trafficType = fields.Nested(traffic_type_schema_exclude.TrafficTypeSchemaExclude)
+    trafficType = fields.Nested(TrafficTypeSchemaExclude)
     creationTime = fields.Integer()
-    tags = fields.List(fields.Nested(tag_schema_exclude.TagSchemaExclude), missing=None)
+    tags = fields.List(fields.Nested(TagSchemaExclude), missing=None)
 
     @post_load
     def load_split(self, data, **kwargs):
