@@ -1,5 +1,9 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
-from splitiorequests.schemas.splits.split_schema_exclude import SplitSchemaExclude
+
+from .split_schema_exclude import SplitSchemaExclude
 from splitiorequests.models.splits.splits import Splits
 
 
